==> plan-1.8.tar.gz: plan-1.8/src/resources.h <==
#if defined LINUX || defined __FreeBSD__
"*foreground:        #000000",
#endif
#ifdef DESKTOP
"*background:        #b1b1b1",
#else
"*background:        #a0a0a0",
#endif
"*colStd:            #101010",
"*colBack:           #b4b4b4",
"*colGrayIcon:       #888888",
"*colWireFrame:      #aaaaaa",
"*colCalBack:        #e0e0e0",
"*colCalShade:       #d0d0d0",
"*colCalToday:       #60f060",
"*colCalFrame:       #e0e0e0",
"*colGrid:           #404040",
"*colWeekday:        #000000",
"*colWeekend:        #c02020",
"*colNote:           #404080",
"*colNoteOff:        #a0a0c0",
#ifdef DESKTOP
"*colToggle:         #c00000",
#else
"*colToggle:         #00ff00",
#endif
"*colRed:            #ff0000",
"*colTextBack:       #c07070",
"*colYearBack:       #e0e0e0",
"*colYearBoxBack:    #d0d0d0",
"*colYearNumber:     #000000",
"*colYearWeekday:    #202020",
"*colYearMonth:      #404080",
"*colYearTitle:      #404080",
"*colYearGrid:       #404040",
"*colHolidayBlack:   #000000",
"*colHolidayRed:     #ff4040",
"*colHolidayGreen:   #008000",
"*colHolidayYellow:  #a0a000",
"*colHolidayBlue:    #0000ff",
"*colHolidayMagenta: #ff00ff",
"*colHolidayCyan:    #008080",
"*colHolidayWhite:   #ffffff",
#if !defined(bsdi) && !defined(LINUX)
"*menubar*fontList:  -*-helvetica-bold-*-normal-*-14-*",
"*fontList:          -*-helvetica-*-r-normal-*-14-*",
"*helpFont:          -*-helvetica-medium-r-normal-*-14-*",
"*calNumberFont:     -*-helvetica-*-r-*-*-34-*",
"*calNumberFontSm:   -*-helvetica-*-r-*-*-14-*",
"*calNoteFont:       -*-helvetica-*-r-*-*-12-*",
"*calBoxWidth:       100",
"*calBoxHeight:      80",
"*calBoxMargin:      20",
"*calArrowWidth:     10",
#else
"*menubar*fontList:  -*-helvetica-bold-*-normal-*-12-*",
"*fontList:          -*-helvetica-*-r-normal-*-12-*",
"*helpFont:          -*-helvetica-medium-r-normal-*-10-*",
"*calNumberFont:     -*-helvetica-medium-r-*-*-20-*",
"*calNumberFontSm:   -*-helvetica-medium-r-*-*-14-*",
"*calNoteFont:       -*-helvetica-medium-r-*-*-8-*",
"*calBoxWidth:       74",
"*calBoxHeight:      54",
"*calBoxMargin:      8",
"*calArrowWidth:     6",
#endif
"*calBoxWidthSm:     40",
"*calBoxHeightSm:    34",
"*calBoxMarginSm:    10",
"*calArrowWidthSm:   6",
"*calBoxTitle:       25",
"*noteWidth:         178",
#ifdef sgi
"*noIcon:            True",
#else
"*noIcon:            False",
#endif
"*showIconTime:      True",
"*showIconDate:      False",
"*frameToday:        False",
"*noMonthShadow:     False",
#ifdef DESKTOP
"*sgiMode:           True",
"*useSchemes:        True",
#endif
#if defined(LINUX)
"*yearTitleFont:     -*-helvetica-*-r-*-*-24-*",
"*yearMonthFont:     -*-helvetica-*-o-*-*-18-*",
#else
"*yearTitleFont:     -*-helvetica-*-r-*-*-34-*",
"*yearMonthFont:     -*-helvetica-*-o-*-*-17-*",
#endif
"*yearWeekdayFont:   -*-helvetica-*-o-*-*-12-*",
"*yearNumberFont:    -*-helvetica-*-r-*-*-12-*",
"*yearMargin:        20",
"*yearGap:           20",
"*yearTitle:         30",
"*yearBoxWidth:      30",
"*yearBoxHeight:     24",
"*dayMargin:         26",
"*dayGap:            4",
"*dayHeadline:       15",
"*dayHourWidth:      80",
"*dayHourHeight:     32",
"*dayBarWidth:       100",
"*weekMargin:        16",
"*weekGap:           6",
"*weekDayWidth:      80",
"*weekHourWidth:     50",
"*weekBarHeight:     20",
"*weekBarGap:        3",
"*weekMaxNote:       200",
"*yovWWidth:         870",
"*yovWHeight:        400",
"*yovDayWidth:       24",
"*colWeekBack:       #e0e0e0",
"*colWeekBoxback:    #c0c0c0",
"*colWeekTitle:      #202020",
"*colWeekGrid:       #606060",
"*colWeekDay:        #404080",
"*colWeekNote:       #202020",
"*colWeekFrame:      #202020",
"*colWeekWarn:       #808080",
"*colWeekUser_0:     #8080c0",
"*colWeekUser_1:     #e07070",
"*colWeekUser_2:     #50d050",
"*colWeekUser_3:     #c070c0",
"*colWeekUser_4:     #b0c050",
"*colWeekUser_5:     #50c0a0",
"*colWeekUser_6:     #e0a020",
"*colWeekUser_7:     #60b0d0",
"*weekTitleFont:     -*-helvetica-*-r-*-*-18-*",
"*weekDayFont:       -*-helvetica-*-o-*-*-14-*",
"*weekHourFont:      -*-helvetica-*-r-*-*-14-*",
"*weekNoteFont:      -*-helvetica-*-r-*-*-14-*",
#ifdef JAPAN
#ifndef sun
#ifdef NEWSOS4
"*jNoteFont:                -*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*",
"*dayform*fontList:         -*-helvetica-*-r-*-*-17-*,16x16kanji=JISX0208.1983-0",
"*dayform*text.fontList:    8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
"*dayform*holiday.fontList: 8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
"*text.fontList:            8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
"*keyform*XmText.fontList:  8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
"*dayinfo.fontList:         -*-helvetica-medium-r-*-*-14-*,14x14kanji=JISX0208.1983-0",
"*weekinfo.fontList:        -*-helvetica-medium-r-*-*-14-*,14x14kanji=JISX0208.1983-0",
"*yovinfo.fontList:         -*-helvetica-medium-r-*-*-14-*,14x14kanji=JISX0208.1983-0",
#else
"*jNoteFont:                 -*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*",
"*dayform*fontList:          -*-helvetica-*-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*dayform*text.fontList:     -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*dayform*holiday.fontList:  -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*text.fontList:             -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*keyform*XmText.fontList:   -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*dayinfo.fontList:          -*-helvetica-medium-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*weekinfo.fontList:         -*-helvetica-medium-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*yovinfo.fontList:          -*-helvetica-medium-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
#endif
#else
"*jNoteFont:                -sun-*-14-*-jisx0208.1983-0",
"*dayform*fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-sun-*-14-*-jisx0208.1983-0;-sun-*-14-*-jisx0201.1976-0:",
"*dayform*text.fontList:    -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
"*dayform*holiday.fontList: -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
"*text.fontList:            -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
"*keyform*XmText.fontList:  -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
"*dayinfo.fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-sun-*-14-*-jisx0208.1983-0;-sun-*-14-*-jisx0201.1976-0:",
"*weekinfo.fontList:        -*-helvetica-*-r-*-14-*-iso8859-1;-sun-*-14-*-jisx0208.1983-0;-sun-*-14-*-jisx0201.1976-0:",
"*yovinfo.fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-sun-*-14-*-jisx0208.1983-0;-sun-*-14-*-jisx0201.1976-0:",
#endif
#endif

==> plan-1.8.2.tar.gz: plan-1.8.2/src/resources.h <==
#if defined LINUX || defined __FreeBSD__
"*foreground:        #000000",
#endif
#ifdef DESKTOP
"*background:        #b1b1b1",
#else
"*background:        #a0a0a0",
#endif
"*colStd:            #101010",
"*colBack:           #b4b4b4",
"*colGrayIcon:       #888888",
"*colWireFrame:      #aaaaaa",
"*colCalBack:        #e0e0e0",
"*colCalShade:       #d0d0d0",
"*colCalToday:       #60f060",
"*colCalFrame:       #e0e0e0",
"*colGrid:           #404040",
"*colWeekday:        #000000",
"*colWeekend:        #c02020",
"*colNote:           #404080",
"*colNoteOff:        #a0a0c0",
#ifdef DESKTOP
"*colToggle:         #c00000",
#else
"*colToggle:         #00ff00",
#endif
"*colRed:            #ff0000",
"*colTextBack:       #c07070",
"*colYearBack:       #e0e0e0",
"*colYearBoxBack:    #d0d0d0",
"*colYearNumber:     #000000",
"*colYearWeekday:    #202020",
"*colYearMonth:      #404080",
"*colYearTitle:      #404080",
"*colYearGrid:       #404040",
"*colHolidayBlack:   #000000",
"*colHolidayRed:     #ff4040",
"*colHolidayGreen:   #008000",
"*colHolidayYellow:  #a0a000",
"*colHolidayBlue:    #0000ff",
"*colHolidayMagenta: #ff00ff",
"*colHolidayCyan:    #008080",
"*colHolidayWhite:   #ffffff",
#if !defined(bsdi) && !defined(LINUX)
"*menubar*fontList:  -*-helvetica-bold-*-normal-*-14-*",
"*fontList:          -*-helvetica-*-r-normal-*-14-*",
"*helpFont:          -*-helvetica-medium-r-normal-*-14-*",
"*calNumberFont:     -*-helvetica-*-r-*-*-34-*",
"*calNumberFontSm:   -*-helvetica-*-r-*-*-14-*",
"*calNoteFont:       -*-helvetica-*-r-*-*-12-*",
"*calBoxWidth:       100",
"*calBoxHeight:      80",
"*calBoxMargin:      20",
"*calArrowWidth:     10",
#else
"*menubar*fontList:  -*-helvetica-bold-*-normal-*-12-*",
"*fontList:          -*-helvetica-*-r-normal-*-12-*",
"*helpFont:          -*-helvetica-medium-r-normal-*-10-*",
"*calNumberFont:     -*-helvetica-medium-r-*-*-20-*",
"*calNumberFontSm:   -*-helvetica-medium-r-*-*-14-*",
"*calNoteFont:       -*-helvetica-medium-r-*-*-8-*",
"*calBoxWidth:       74",
"*calBoxHeight:      54",
"*calBoxMargin:      8",
"*calArrowWidth:     6",
#endif
"*calBoxWidthSm:     40",
"*calBoxHeightSm:    34",
"*calBoxMarginSm:    10",
"*calArrowWidthSm:   6",
"*calBoxTitle:       25",
"*noteWidth:         178",
#ifdef sgi
"*noIcon:            True",
#else
"*noIcon:            False",
#endif
"*showIconTime:      True",
"*showIconDate:      False",
"*frameToday:        False",
"*noMonthShadow:     False",
#ifdef DESKTOP
"*sgiMode:           True",
"*useSchemes:        True",
#endif
#if defined(LINUX)
"*yearTitleFont:     -*-helvetica-*-r-*-*-24-*",
"*yearMonthFont:     -*-helvetica-*-o-*-*-18-*",
#else
"*yearTitleFont:     -*-helvetica-*-r-*-*-34-*",
"*yearMonthFont:     -*-helvetica-*-o-*-*-17-*",
#endif
"*yearWeekdayFont:   -*-helvetica-*-o-*-*-12-*",
"*yearNumberFont:    -*-helvetica-*-r-*-*-12-*",
"*yearMargin:        20",
"*yearGap:           20",
"*yearTitle:         30",
"*yearBoxWidth:      30",
"*yearBoxHeight:     24",
"*dayMargin:         26",
"*dayGap:            4",
"*dayHeadline:       15",
"*dayHourWidth:      80",
"*dayHourHeight:     32",
"*dayBarWidth:       100",
"*weekMargin:        16",
"*weekGap:           6",
"*weekDayWidth:      80",
"*weekHourWidth:     50",
"*weekBarHeight:     20",
"*weekBarGap:        3",
"*weekMaxNote:       200",
"*yovWWidth:         870",
"*yovWHeight:        400",
"*yovDayWidth:       24",
"*colWeekBack:       #e0e0e0",
"*colWeekBoxback:    #c0c0c0",
"*colWeekTitle:      #202020",
"*colWeekGrid:       #606060",
"*colWeekDay:        #404080",
"*colWeekNote:       #202020",
"*colWeekFrame:      #202020",
"*colWeekWarn:       #808080",
"*colWeekUser_0:     #8080c0",
"*colWeekUser_1:     #e07070",
"*colWeekUser_2:     #50d050",
"*colWeekUser_3:     #c070c0",
"*colWeekUser_4:     #b0c050",
"*colWeekUser_5:     #50c0a0",
"*colWeekUser_6:     #e0a020",
"*colWeekUser_7:     #60b0d0",
"*weekTitleFont:     -*-helvetica-*-r-*-*-18-*",
"*weekDayFont:       -*-helvetica-*-o-*-*-14-*",
"*weekHourFont:      -*-helvetica-*-r-*-*-14-*",
"*weekNoteFont:      -*-helvetica-*-r-*-*-14-*",
#ifdef JAPAN
#ifndef sun
#ifdef NEWSOS4
"*jNoteFont:                -*-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-*",
"*dayform*fontList:         -*-helvetica-*-r-*-*-17-*,16x16kanji=JISX0208.1983-0",
"*dayform*text.fontList:    8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
"*dayform*holiday.fontList: 8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
"*text.fontList:            8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
"*keyform*XmText.fontList:  8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
"*dayinfo.fontList:         -*-helvetica-medium-r-*-*-14-*,14x14kanji=JISX0208.1983-0",
"*weekinfo.fontList:        -*-helvetica-medium-r-*-*-14-*,14x14kanji=JISX0208.1983-0",
"*yovinfo.fontList:         -*-helvetica-medium-r-*-*-14-*,14x14kanji=JISX0208.1983-0",
#else
"*jNoteFont:                -*-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-*",
"*dayform*fontList:          -*-helvetica-*-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*dayform*text.fontList:     -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*dayform*holiday.fontList:  -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*text.fontList:             -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*keyform*XmText.fontList:   -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*dayinfo.fontList:          -*-helvetica-medium-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*weekinfo.fontList:         -*-helvetica-medium-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
"*yovinfo.fontList:          -*-helvetica-medium-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
#endif
#else
"*jNoteFont:                -*-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-*",
"*dayform*fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0201.1976-0;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-0:",
"*dayform*text.fontList:    -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
"*dayform*holiday.fontList: -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
"*text.fontList:            -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
"*keyform*XmText.fontList:  -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
"*dayinfo.fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0201.1976-0;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-0:",
"*weekinfo.fontList:        -*-helvetica-*-r-*-14-*-iso8859-1;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0201.1976-0;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-0:",
"*yovinfo.fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0201.1976-0;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-0:",
#endif
#endif
